# Autogenerated by nbdev

d = { 'settings': { 'allowed_cell_metadata_keys': '',
                'allowed_metadata_keys': '',
                'audience': 'Developers',
                'author': 'Hung P. Do, PhD',
                'author_email': 'hdocmsu@gmail.com',
                'black_formatting': 'False',
                'branch': 'main',
                'clean_ids': 'True',
                'copyright': '@hdocmsu',
                'custom_sidebar': 'False',
                'description': 'A test project using nbdev',
                'doc_baseurl': '/nbdev_cards/',
                'doc_host': 'https://hdocmsu.github.io',
                'doc_path': '_docs',
                'git_url': 'https://github.com/hdocmsu/nbdev_cards/',
                'host': 'github',
                'jupyter_hooks': 'True',
                'keywords': 'nbdev',
                'language': 'English',
                'lib_name': 'nbdev-cards2022',
                'lib_path': 'nbdev_cards',
                'license': 'apache2',
                'min_python': '3.8',
                'nbs_path': 'nbs',
                'readme_nb': 'index.ipynb',
                'recursive': 'False',
                'status': '2',
                'title': 'cards',
                'tst_flags': 'notest',
                'user': 'hdocmsu',
                'version': '0.0.7'},
  'syms': { 'nbdev_cards.card': { 'nbdev_cards.card.Card': 'https://hdocmsu.github.io/nbdev_cards/nbdev_cards.card.html#card',
                                  'nbdev_cards.card.ranks': 'https://hdocmsu.github.io/nbdev_cards/nbdev_cards.card.html#ranks',
                                  'nbdev_cards.card.suits': 'https://hdocmsu.github.io/nbdev_cards/nbdev_cards.card.html#suits'},
            'nbdev_cards.deck': { 'nbdev_cards.deck.Deck': 'https://hdocmsu.github.io/nbdev_cards/nbdev_cards.deck.html#deck',
                                  'nbdev_cards.deck.Deck.pop': 'https://hdocmsu.github.io/nbdev_cards/nbdev_cards.deck.html#deck.pop',
                                  'nbdev_cards.deck.Deck.remove': 'https://hdocmsu.github.io/nbdev_cards/nbdev_cards.deck.html#deck.remove',
                                  'nbdev_cards.deck.Deck.shuffle': 'https://hdocmsu.github.io/nbdev_cards/nbdev_cards.deck.html#deck.shuffle',
                                  'nbdev_cards.deck.draw_n': 'https://hdocmsu.github.io/nbdev_cards/nbdev_cards.deck.html#draw_n'}}}